CompressionEstimate class

A pre-flight estimate produced without actually encoding.

Constructors

CompressionEstimate({required int estimatedSizeBytes, required int estimatedBitrateKbps, required int targetWidth, required int targetHeight})
const
CompressionEstimate.fromMap(Map m)
factory

Properties

estimatedBitrateKbps int
final
estimatedSizeBytes int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetHeight int
final
targetWidth int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited