keepOriginalIfLarger property

bool keepOriginalIfLarger
final

If the compressed output would be larger than the source (common when re-encoding an already-compressed JPEG, or with lossless), keep the original untouched and mark the result ImageCompressResult.skipped. Defaults to true. ImageCompressResult.outputPath then points at the source, with its original size/format/dimensions.

Implementation

final bool keepOriginalIfLarger;