CompressionProgress class
Live progress event streamed during compression.
Constructors
- CompressionProgress({required String id, required double progress, int? estimatedRemainingMs, int? currentOutputBytes})
-
const
- CompressionProgress.fromMap(Map m)
-
factory
Properties
- currentOutputBytes → int?
-
final
- estimatedRemainingMs → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Job id — matches the id returned by FlutterCompress.compress.
final
- progress → double
-
0.0 – 1.0.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited